@@ -37,8 +37,7 @@ cd ..
 
 echo "Compressing..."
 ZUTTY="zutty-${DFSG_VERSION}"
+ZUTTYTAR="${ZUTTY}.tar.xz"
 test ! -d ${ZUTTY} && mv ${TARGET} ${ZUTTY}
-test ! -e ./${ZUTTY}.tar.xz && tar --create --xz --file ./${ZUTTY}.tar.xz --exclude-vcs --totals ${ZUTTY}
-rm -rf ${ZUTTY}
-
-echo "Repackaged as ${ZUTTY}.tar.xz"
+test -e ./${ZUTTYTAR} && rm -rf ${ZUTTY} && echo "Seems ${ZUTTYTAR} is already here" && exit 0
+tar --create --xz --file ./${ZUTTYTAR} --exclude-vcs --totals ${ZUTTY} && rm -rf ${ZUTTY} && echo "Repackaged as ${ZUTTYTAR}"
